@@ -1,12 +1,9 @@
 import base64
 import datetime
 import gzip
-from typing import List
-
 import pandas as pd
 import requests
 import json
-import io
 
 
 class SpotifyCredential:
@@ -17,7 +14,7 @@ class SpotifyCredential:
     range_api_success = [200, 201, 202, 203, 204, 205, 206, 207, 208, 226]
     token_url = "https://accounts.spotify.com/api/token"
 
-    def __init__(self, client_id: str, client_secret:str):
+    def __init__(self, client_id, client_secret):
         """
         Função que recebe os parametros necessários para a autenticação
         Args:
@@ -303,8 +300,7 @@ class SpotifyPrivate(SpotifyCredential):
     Classe que faz todas as funções relacionadas com a API do spotify, desde autenticação até a chamada do API Privada
     """
 
-    def __init__(self, client_id: str, client_secret: str, licensor: str, access_token_const: str,
-                 date: datetime.datetime.date):
+    def __init__(self, client_id, client_secret, licensor, access_token_const, date):
         """
         Função que recebe os parametros necessários para a autenticação
         Args:
@@ -320,7 +316,7 @@ class SpotifyPrivate(SpotifyCredential):
         self.licensor = licensor
         self.access_token_const = access_token_const
 
-    def get_data_streams(self, country: str) -> requests.models.Response:
+    def get_data_streams(self, country) -> requests.models.Response:
         """
         Faz a request para o endpoint streams
         Args:
@@ -386,16 +382,14 @@ class SpotifyPrivate(SpotifyCredential):
         return {"Authorization": f"Bearer {self.access_token_const}"}
 
     @staticmethod
-    def request2json(request: requests.models.Response) -> List[dict]:
+    def request2json(request):
         """
-        Função que transforma a resposta da request em um json
+        Função que transforma a resposta da request em um dataframe
         Args:
             request: request feita para o endpoint
         Returns:
-            Json com a resposta da request
+            DataFrame com os dados da request
         """
-        if request.status_code != 200:
-            print(f'Erro na requisição: {request}')
         decompressed_response = gzip.decompress(request.content)
         my_json = decompressed_response.decode('utf-8')
         my_json = f'[{my_json}]'
@@ -403,50 +397,50 @@ class SpotifyPrivate(SpotifyCredential):
         my_json = my_json.replace('}{', '},{')
         return json.loads(my_json)
 
-    def get_tracks(self) -> List[dict]:
+    def get_tracks(self) -> pd.DataFrame:
         """
-        Função que retorna objeto Json do endpoint tracks
+        Função que retorna o dataframe do endpoint tracks
         Args:
             type: Extensão do arquivo que vai ser escrito
         Returns:
-            Json tracks
+            DataFrame tracks
         """
         return self.request2json(self.get_data_tracks())
 
-    def get_users(self) -> List[dict]:
+    def get_users(self) -> pd.DataFrame:
         """
-        Função que retorna objeto Json do endpoint users
+        Função que retorna o dataframe do endpoint users
         Args:
             type: Extensão do arquivo que vai ser escrito
         Returns:
-            Json users
+            DataFrame users
         """
         return self.request2json(self.get_data_users())
 
-    def get_streams(self, country: str) -> List[dict]:
+    def get_streams(self, country) -> pd.DataFrame:
         """
-        Função que retorna o objeto Json do endpoint streams para um país específico
+        Função que retorna o dataframe do endpoint streams para um país específico
         Args:
             country: Code of the country
         Returns:
-            Json streams de um país
+            DataFrame streams de um país
         """
         return self.request2json(self.get_data_streams(country))
 
-    def get_sub_30_streams(self, country: str) -> List[dict]:
+    def get_sub_30_streams(self, country) -> pd.DataFrame:
         """
-        Função que retorna o objeto Json do endpoint sub 30 secs streams para um país específico
+        Função que retorna o dataframe do endpoint sub30_secs_streams para um país específico
         Args:
             country: Code of the country
         Returns:
-            Json sub 30 secs streams de um país
+            DataFrame sub30_secs_streams streams de um país
         """
         return self.request2json(self.get_data_sub_30_secs_streams(country))
 
-    def get_aggregated_streams(self) -> List[dict]:
+    def get_aggregated_streams(self) -> pd.DataFrame:
         """
-        Função que retorna o objeto Json do endpoint aggregated streams
+        Função que retorna o dataframe do endpoint aggregated_streams
         Returns:
-            Json aggregated streams
+            DataFrame aggregated_streams
         """
         return self.request2json(self.get_data_aggregated_streams())
